slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSGetConvergedReason

Gets the reason why the EPSSolve() iteration was stopped.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSGetConvergedReason(EPS eps,EPSConvergedReason *reason)

Not Collective

### Input Parameter

| eps | - the eigensolver context

### Output Parameter

| reason | - negative value indicates diverged, positive value converged

### Options Database Key

| -eps_converged_reason | - print the reason to a viewer

### Notes

Possible values for reason are

| EPS_CONVERGED_TOL | - converged up to tolerance
| EPS_CONVERGED_USER | - converged due to a user-defined condition
| EPS_DIVERGED_ITS | - required more than max_it iterations to reach convergence
| EPS_DIVERGED_BREAKDOWN | - generic breakdown in method
| EPS_DIVERGED_SYMMETRY_LOST | - pseudo-Lanczos was not able to keep symmetry

Can only be called after the call to EPSSolve() is complete.

### See Also

EPSSetTolerances(), EPSSolve(), EPSConvergedReason

### Level

intermediate

### Location

src/eps/interface/epssolve.c

### Examples

src/eps/tutorials/ex29.c.html
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages